@@ -23,7 +23,7 @@ WSGI application everything will work properly.
 
 Example:
 
-.. code-block:: Python
+.. code-block:: python
     
     #yourpackage/__init__.py
     
@@ -63,7 +63,7 @@ thousands of times per request, the performance of the proxy will start to
 become more noticeable. In that circumstance, the problem can be avoided by
 getting at the actual object via the proxy with the ``_current_obj`` function:
 
-.. code-block:: Python
+.. code-block:: python
     
     #sessions.py
     Session = StackedObjectProxy()
@@ -120,6 +120,18 @@ class StackedObjectProxy(object):
         self.__dict__['____local__'] = threadinglocal.local()
         if default is not NoDefault:
             self.__dict__['____default_object__'] = default
+
+    def __dir__(self):
+        """Return a list of the StackedObjectProxy's and proxied
+        object's (if one exists) names.
+        """
+        dir_list = dir(self.__class__) + self.__dict__.keys()
+        try:
+            dir_list.extend(dir(self._current_obj()))
+        except TypeError:
+            pass
+        dir_list.sort()
+        return dir_list
     
     def __getattr__(self, attr):
         return getattr(self._current_obj(), attr)
@@ -186,7 +198,7 @@ class StackedObjectProxy(object):
         
         This should be used like:
         
-        .. code-block:: Python
+        .. code-block:: python
 
             obj = yourobject()
             module.glob = StackedObjectProxy()
@@ -323,13 +335,17 @@ class RegistryManager(object):
     object which is a Registry instance.
         
     """
-    def __init__(self, application):
+    def __init__(self, application, streaming=False):
         self.application = application
+        self.streaming = streaming
         
     def __call__(self, environ, start_response):
         app_iter = None
         reg = environ.setdefault('paste.registry', Registry())
         reg.prepare()
+        if self.streaming:
+            return self.streaming_iter(reg, environ, start_response)
+        
         try:
             app_iter = self.application(environ, start_response)
         except Exception, e:
@@ -358,6 +374,36 @@ class RegistryManager(object):
             reg.cleanup()
         
         return app_iter
+    
+    def streaming_iter(self, reg, environ, start_response):
+        try:
+            for item in self.application(environ, start_response):
+                yield item
+        except Exception, e:
+            # Regardless of if the content is an iterable, generator, list
+            # or tuple, we clean-up right now. If its an iterable/generator
+            # care should be used to ensure the generator has its own ref
+            # to the actual object
+            if environ.get('paste.evalexception'):
+                # EvalException is present in the WSGI stack
+                expected = False
+                for expect in environ.get('paste.expected_exceptions', []):
+                    if isinstance(e, expect):
+                        expected = True
+                if not expected:
+                    # An unexpected exception: save state for EvalException
+                    restorer.save_registry_state(environ)
+            reg.cleanup()
+            raise
+        except:
+            # Save state for EvalException if it's present
+            if environ.get('paste.evalexception'):
+                restorer.save_registry_state(environ)
+            reg.cleanup()
+            raise
+        else:
+            reg.cleanup()
+
 
 class StackedObjectRestorer(object):
     """Track StackedObjectProxies and their proxied objects for automatic
