@@ -30,6 +30,7 @@ import os
 import md5
 import datetime
 import threading
+import tempfile
 
 try:
     import cPickle
@@ -79,7 +80,7 @@ class SessionFactory(object):
                  session_class=None,
                  session_expiration=60*12, # in minutes
                  **session_class_kw):
-        
+
         self.created = False
         self.used = False
         self.environ = environ
@@ -133,7 +134,9 @@ class SessionFactory(object):
         id() is incorporated into the generation.  Relies on md5 and
         returns a 32 character long string.
         """
-        r = [time.time(), random.random(), os.times()]
+        r = [time.time(), random.random()]
+        if hasattr(os, 'times'):
+            r.append(os.times())
         if for_object is not None:
             r.append(id(for_object))
         md5_hash = md5.new(str(r))
@@ -169,7 +172,7 @@ cleanup_cycle = datetime.timedelta(seconds=15*60) #15 min
 
 class FileSession(object):
 
-    def __init__(self, sid, create=False, session_file_path='/tmp',
+    def __init__(self, sid, create=False, session_file_path=tempfile.gettempdir(),
                  chmod=None,
                  expiration=2880, # in minutes: 48 hours
                  ):
@@ -293,7 +296,7 @@ def make_session_middleware(
 
       session_expiration:
           The time each session lives, in minutes.  This controls
-          the cookie expiration.  Default 12 hours.  
+          the cookie expiration.  Default 12 hours.
 
       expiration:
           The time each session lives on disk.  Old sessions are
