@@ -432,12 +432,14 @@ class StaticURLParser(object):
                  cache_max_age=None):
         if os.path.sep != '/':
             directory = directory.replace(os.path.sep, '/')
-        self.directory = directory
+        self.directory = os.path.normcase(os.path.abspath(directory))
         self.root_directory = root_directory
         if root_directory is not None:
             self.root_directory = os.path.normpath(self.root_directory)
         else:
             self.root_directory = directory
+        self.root_directory = os.path.normcase(os.path.normpath(
+            os.path.abspath(self.root_directory)))
         self.cache_max_age = cache_max_age
         if os.path.sep != '/':
             directory = directory.replace('/', os.path.sep)
@@ -452,7 +454,8 @@ class StaticURLParser(object):
             filename = 'index.html'
         else:
             filename = request.path_info_pop(environ)
-        full = os.path.normpath(os.path.join(self.directory, filename))
+        full = os.path.normcase(os.path.normpath(
+            os.path.join(self.directory, filename)))
         if os.path.sep != '/':
             full = full.replace('/', os.path.sep)
         if self.root_directory is not None and not full.startswith(self.root_directory):
@@ -562,7 +565,8 @@ class PkgResourcesParser(StaticURLParser):
             filename = 'index.html'
         else:
             filename = request.path_info_pop(environ)
-        resource = os.path.normpath(self.resource_name + '/' + filename)
+        resource = os.path.normcase(os.path.normpath(
+                    self.resource_name + '/' + filename))
         if self.root_resource is not None and not resource.startswith(self.root_resource):
             # Out of bounds
             return self.not_found(environ, start_response)
