@@ -58,33 +58,6 @@ def test_template():
     assert '<p>A fun and <b>happy</b> message.</p>' in \
            e.html({'ping': 'fun', 'pong': 'happy'})
 
-def test_iterator_application():
-    """
-    This tests to see that an iterator's exceptions are caught by
-    HTTPExceptionHandler
-    """
-    def basic_found(environ, start_response):
-        raise HTTPFound("/bing/foo")
-        return ['result']
-    app = HTTPExceptionHandler(basic_found)
-    (status, headers, content, errors) = raw_interactive(app)
-    assert '302 Found' == status
-    def make_iter(application):
-        def iterapp(environ, start_response):
-            result = application(environ, start_response)
-            for chunk in result:
-                yield chunk
-        return iterapp
-    app = HTTPExceptionHandler(make_iter(basic_found))
-    (status, headers, content, errors) = raw_interactive(app)
-    assert '302 Found' == status
-    def iterate_found(environ, start_response):
-        raise HTTPFound("/bing/foo")
-        yield 'result'
-    app = HTTPExceptionHandler(iterate_found)
-    (status, headers, content, errors) = raw_interactive(app)
-    assert '302 Found' == status
-
 def test_redapp():
     """ check that redirect returns the correct, expected results """
     saved = []
@@ -103,7 +76,7 @@ def test_redapp():
         '302 Found\n'
         'This resource was found at /bing/foo;\n'
         'you should be redirected automatically.\n')
-    assert "text/plain" == header_value(saved[1][1],'content-type')
+    assert "text/plain; charset=utf8" == header_value(saved[1][1],'content-type')
     assert "/bing/foo" == header_value(saved[1][1],'location')
 
 def test_misc():
